import request from '@/router/axios'


export function cancelOrderApi(parameter) {
  return request({
    url: '/admin/merchantMallOrder/cancelOrder',
    method: 'get',
    params:parameter
  })
}

export function delObj(parameter) {
  return request({
    url: '/admin/merchantMallOrder',
    method: 'delete',
    params:parameter
  })
}


export function fetchList(query) {
  return request({
    url: '/admin/merchantMallOrder/page',
    method: 'get',
    params: query
  })
}
export function putObj(obj) {
  return request({
    url: '/admin/merchantMallOrder',
    method: 'put',
    params: obj
  })
}

export function shipsImmediatelyApi(query) {
  return request({
    url: '/admin/merchantMallOrder/shipsImmediately',
    method: 'put',
    params: query
  })
}

export function getOrderInfo(params) {
  return request({
    url: '/admin/merchantMallOrder/queryOrderDetails',
    method: 'get',
    params:params
  })
}

export function cancelOrderMethod(query) {
  return request({
    url: '/admin/merchantMallOrder/cancelOrder',
    method: 'get',
    params: query
  })
}
export function viewLogisticsApi(query) {
  return request({
    url: '/admin/merchantMallOrder/viewLogistics',
    method: 'get',
    params: query
  })
}

//
// export function getShopDetails(params) {
//   return request({
//     url: '/general/mallOrder/getShopDetails',
//     method: 'get',
//     params
//   })
// }
// export function isVirtualGoods(query) {
//   return request({
//     url: '/admin/merchantMallOrder/isVirtualGoods',
//     method: 'get',
//     params: query
//   })
// }

// export function getObj(id) {
//   return request({
//     url: '/general/mallOrder/' + id,
//     method: 'get'
//   })
// }

//
// export function addObj(obj) {
//   return request({
//     url: '/general/mallOrder',
//     method: 'post',
//     data: obj
//   })
// }
//


//
// export function confirmPayObj(obj) {
//   return request({
//     url: '/general/mallOrder/confirmPayment',
//     method: 'put',
//     params: obj
//   })
// }
//

//
//

// export function shopClass(params) {
//   return request({
//     url: '/general/mallOrder/getShopClassOptions',
//     method: 'get',
//     params
//   })
// }
//
// export function searchShopClass(params) {
//   return request({
//     url: '/general/mallOrder/searchShopClassOptions',
//     method: 'get',
//     params
//   })
// }
//
// export function authApply(data) {
//   return request({
//     url: '/general/mallOrder/verifyMerchantApply',
//     method: 'post',
//     data
//   })
// }
//
// export function fetchShopList(data) {
//   return request({
//     url: '/general/mallOrder/searchList',
//     method: 'post',
//     data
//   })
// }
//

//
// export function editShopInfo(data) {
//   return request({
//     url: '/general/mallOrder/editShopInfo',
//     method: 'post',
//     data
//   })
// }
//
// export function editDeposit(params) {
//   return request({
//     url: '/general/mallOrder/editDeposit',
//     method: 'get',
//     params
//   })
// }
//
// export function resetPassword(params) {
//   return request({
//     url: '/general/mallOrder/resetPassword',
//     method: 'get',
//     params
//   })
// }
//
// export function block(params) {
//   return request({
//     url: '/general/mallOrder/blocked',
//     method: 'get',
//     params
//   })
// }
//
// export function unBlock(params) {
//   return request({
//     url: '/general/mallOrder/unBlock',
//     method: 'get',
//     params
//   })
// }
